regesta-cli-0.0.0 is not a library.
regesta-cli
Command-line publisher and verifier for the Regesta package registry draft.
Regesta is an early draft and experimental implementation, not a production registry. The CLI currently focuses on the npm-first V0 development path:
- generating Ed25519 publish keys;
- packing source and npm install artifacts;
- signing publish requests with Ed25519 or
ssh-ed25519; - publishing to a Regesta registry endpoint;
- reading public verification, event-log, package-state, and mirror APIs.
See https://regesta.dev/ for the project documentation.